#include "SDL/SDL.h"

#define VERSION         "0.1.5"
#define WIDTH           640
#define HEIGHT          480
#define BPP             32
#define NAME_MAXLEN     16
#define MAX_HIGHENTRIES 20
#define MAX_TILES       99
#define TILE_WIDTH      60
#define TILE_HEIGHT     60
#define WINDOWX         0
#define WINDOWY         0
#define TILESET_DEFAULT "marble"
#define GRAVITY         100
#define DELAY           20
#define TILE_EMPTY      00
#define TILE_WALL       01
#define TILE_FIRST	    40
#define IsTile(a)       ((a)>=TILE_FIRST)
#define IsEmpty(a)      ((a)==TILE_EMPTY)

#define DIR_DATA        "data/"
#define DIR_BACKGROUND  DIR_DATA"backgrounds/"
#define DIR_LEVEL       DIR_DATA"levels/"
#define DIR_SAVE        DIR_DATA"saves/"
#define DIR_IMAGE       DIR_DATA"images/"
#define DIR_MUSIC       DIR_DATA"music/"
#define DIR_SOUND       DIR_DATA"sounds/"
#define DIR_TILESET     DIR_DATA"tilesets/"
#define DIR_FONT        DIR_DATA"fonts/"
#define FILE_HIGH       DIR_DATA"high.dat"

#define FONTNAME_SCORE  DIR_FONT"gas.ttf"
#define FONTNAME_NORMAL DIR_FONT"bankgothic.ttf"
#define FONTSIZE_SCORE  30
#define FONTSIZE_SMALL  16

#define BACKGROUND_MENU DIR_BACKGROUND"title_background.png"
#define BACKGROUND_BASE DIR_BACKGROUND"base.png"
#define BACKGROUND_EDIT DIR_BACKGROUND"edit.png"
#define BACKGROUND_HELP DIR_BACKGROUND"help.png"
#define IMAGE_QUIT      DIR_IMAGE"menu_quit.png"
#define IMAGE_PLAY      DIR_IMAGE"menu_play.png"
#define IMAGE_EDIT      DIR_IMAGE"menu_edit.png"
#define IMAGE_YES       DIR_IMAGE"menu_yes.png"
#define IMAGE_NO        DIR_IMAGE"menu_no.png"
#define IMAGE_HELP      DIR_IMAGE"menu_help.png"
#define IMAGE_HIGHS     DIR_IMAGE"menu_highs.png"
#define IMAGE_ASKQUIT   DIR_IMAGE"ask_quit.png"
#define IMAGE_OPTIONS   DIR_IMAGE"menu_options.png"
#define IMAGE_LOGO      DIR_IMAGE"title_brix.png"
#define IMAGE_BUILD     DIR_IMAGE"button_build.png"
#define IMAGE_CLEAR     DIR_IMAGE"button_clear.png"
#define IMAGE_ERASE     DIR_IMAGE"button_erase.png"
#define IMAGE_NORMAL    DIR_IMAGE"button_normal.png"
#define IMAGE_LOAD	DIR_IMAGE"load.png"
#define IMAGE_SAVE	DIR_IMAGE"save.png"
#define IMAGE_CLOCK	DIR_IMAGE"clock.png"
#define IMAGE_RELOAD	DIR_IMAGE"reload.png"
#define IMAGE_LIGHT_GREEN DIR_IMAGE"light_green.png"
#define IMAGE_LIGHT_YELLOW DIR_IMAGE"light_yellow.png"
#define IMAGE_LIGHT_RED DIR_IMAGE"light_red.png"

#define ALPHA1	80
#define ALPHA2  160

struct high_entry
{
    long score;
    char name[NAME_MAXLEN+1];
};

typedef high_entry high[MAX_HIGHENTRIES];
typedef int level[8][8];

enum modes {MODE_NORMAL,MODE_BUILD,MODE_CLEAR,MODE_ERASE,MODE_RELOAD,MODE_END};
const int cost[]={    0,       100,       200,      1000,        500,       0};

SDL_Surface *LoadImage(char *fname,int Rkey=0,int Gkey=0,int Bkey=0);
void PutSurface(SDL_Surface *src,SDL_Surface *dest,SDL_Rect pos,int clipx=-1,int clipy=-1,int width=-1,int height=-1);
void PutSurface(SDL_Surface *src,SDL_Surface *dest,int x=0,int y=0,int clipx=-1,int clipy=-1,int width=-1,int height=-1);
int LoadLevel(char *fname,level &t);
int SaveLevel(char *fname,level t,int timelimit);
int CheckMatches(level &table,level drop);
int Input(SDL_Surface *screen,TTF_Font *font,SDL_Color color,int x,int y,char *s,int maxlen);
int SaveHigh(long score,char *name);
